# duablo

A command-line tool to dual-launch multiple instances of Diablo II: Resurrected.

## License

Copyright (C) 2025 Garrett HE <garrett.he@outlook.com>

The BSD 3-Clause License, see [LICENSE](./LICENSE).

